@@ -250,7 +250,7 @@ def safe_symlink(directory, filename, target):
         raise
 
 
-# pylint: disable=too-many-arguments
+# pylint: disable=too-many-arguments, too-many-positional-arguments
 def save_config(pconfig, cfgname, cfgdata, cfgdir, localdir, profiledir,
                 policy_was_empty, allow_symlinking=False):
     local_cfg_path = os.path.join(localdir, cfgname + '-*.config')
@@ -373,16 +373,16 @@ def apply_policy(pconfig, profile=None, print_enabled=True,
                 eprint("Warning: Using 'update-crypto-policies --set FIPS' "
                        "is not sufficient for")
                 eprint("         FIPS compliance.")
-                eprint("         Use 'fips-mode-setup --enable' "
-                       "command instead.")
+                eprint("         The kernel must be started with `fips=1`"
+                       " for FIPS compliance.")
             elif fips_mode():
-                eprint("Warning: Using 'update-crypto-policies --set' "
-                       "in FIPS mode will make the system")
+                eprint("Warning: Using 'update-crypto-policies --set' in FIPS"
+                       " mode will make the system")
                 eprint("         non-compliant with FIPS.")
-                eprint("         It can also break "
-                       "the ssh access to the system.")
-                eprint("         Use 'fips-mode-setup --disable' "
-                       "to disable the system FIPS mode.")
+                eprint("         It can also break ssh access to the system.")
+                eprint("         Reboot without `fips=1` on the kernel command"
+                       " line to disable the")
+                eprint("         system FIPS mode.")
 
     if base_dir == DEFAULT_BASE_DIR and os.geteuid() != 0:
         eprint("You must be root to run update-crypto-policies.")
